#include "spawn.h"

#include "..\algorithms.h"

void botInfo::gotHelp(Player *p, Command *c)
{
	// List commands

	if (!*c->final)
	{
		switch (p->access)
		{
		case OP_Duke:
		case OP_Baron:
		case OP_King:
		case OP_Emperor:
		case OP_RockStar:
		case OP_Q:
		case OP_God:
		case OP_Owner:
			{	// Owner-level commands
			}
		case OP_SysOp:
			{	// SysOp-level commands
			}
		case OP_SuperModerator:
			{	// SuperModerator-level commands
			}
		case OP_Moderator:
			{	// Moderator-level commands
				sendPrivate(p, "Ext: !energy !reset !resetnow");
			}
			break;
		case OP_Limited:
			{	// Limited-level commands
			}
		case OP_Player:
			{	// Player-level commands
				sendPrivate(p, "!rank (display your current rank)");
				sendPrivate(p, "!rules (display game rules)");
			}
		}

		return;
	}

	// Specific command help

	switch (p->access)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
			if (c->checkParam("owner") || c->checkParam("all"))
			{
//				sendPrivate(p, "Ext: ");
			}
		}
	case OP_SysOp:
		{	// SysOp-level commands
			if (c->checkParam("sop") || c->checkParam("all"))
			{
//				sendPrivate(p, "Ext: ");
			}
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
			if (c->checkParam("smod") || c->checkParam("all"))
			{
//				sendPrivate(p, "Ext: ");
			}
		}
	case OP_Moderator:
		{	// Moderator-level commands
			if (c->checkParam("mod") || c->checkParam("all"))
			{
				sendPrivate(p, "Ext: !energy !reset !resetnow");
			}
			else if (c->checkParam("energy"))
			{
				sendPrivate(p, "!energy [on/off] (toggle energy viewing when players enter)");
			}
			else if (c->checkParam("reset"))
			{
				sendPrivate(p, "!reset [on/off] (reset scores when players enter)");
			}
			else if (c->checkParam("resetnow"))
			{
				sendPrivate(p, "!resetnow (reset scores now)");
			}
		}
	case OP_Limited:
		{	// Limited-level commands
		}
	case OP_Player:
		{	// Player-level commands
			if (c->checkParam("rank"))
			{
				sendPrivate(p, "!rank (display your current rank)");
			}
			else if (c->checkParam("rules"))
			{
				sendPrivate(p, "!rules (display game rules)");
			}
		}
	}
}

void botInfo::gotCommand(Player *p, Command *c)
{
	if (!p) return;
	if (!c) return;

	switch (p->access)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
			if (c->check("version"))
			{
				sendPrivate(p, "[name:rankbot.dll] [maker:cat02e@fsu.edu] [build:6]");
			}
		}
	case OP_Moderator:
		{	// Moderator-level commands
			if (c->check("resetnow"))
			{
				sendPublic("*scorereset");
				sendPublic("*arena Arena scores reset.");
			}
			else if (c->check("reset"))
			{
				if (c->checkParam("on"))
				{
					reset_scores = true;

					sendPrivate(p, "Now reseting scores");
				}
				else if (c->checkParam("off"))
				{
					reset_scores = false;

					sendPrivate(p, "No longer reseting scores");
				}
				else
				{
					if (reset_scores)
					{
						sendPrivate(p, "Reseting scores");
					}
					else
					{
						sendPrivate(p, "Not reseting scores");
					}
				}
			}
			else if (c->check("energy"))
			{
				if (c->checkParam("on"))
				{
					energy_on = true;

					sendPrivate(p, "Now granting energy viewing");
				}
				else if (c->checkParam("off"))
				{
					energy_on = false;

					sendPrivate(p, "No longer granting energy viewing");
				}
				else
				{
					if (energy_on)
					{
						sendPrivate(p, "Granting energy viewing");
					}
					else
					{
						sendPrivate(p, "Not granting energy viewing");
					}
				}
			}
		}
	case OP_Limited:
		{	// Limited-level commands
		}
	case OP_Player:
		{	// Player-level commands
			if (c->check("rank"))
			{
				int rank = get_tag(p, 0);

				String s;
				s += "Current rank: ";
				s += setts.RankName[rank];

				if (rank != NUM_RANKS - 1)
				{
					s += "  Next rank: ";
					s += setts.RankName[rank + 1];
					s += "  Points required: ";
					s += setts.RankPoints[rank + 1];
					s += "  Points remaining: ";
					s += setts.RankPoints[rank + 1] - (p->score.flagPoints + p->score.killPoints);
				}

				sendPrivate(p, s);

				s = "*warn You may only use ships: ";

				for (int i = 0; i < NUM_SHIPS; ++i)
				{
					if ((rank + 1) >= setts.ShipLevels[i])
					{
						s += setts.ShipName[i];
						s += "#";
						s += i + 1;
						s += ", ";
					}
				}

				s += "until your next promotion.";

				sendPrivate(p, s);
			}
			else if (c->check("rules"))
			{
				for (int i = 0; i < NUM_RULES; ++i)
				{
					String s = setts.Rules[i];
					if (!s.IsEmpty()) sendPrivate(p, s);
				}
			}
		}
	}
}

void botInfo::gotRemoteHelp(char *p, Command *c, Operator_Level l)
{
	// List commands

	if (!*c->final)
	{
		switch (l)
		{
		case OP_Duke:
		case OP_Baron:
		case OP_King:
		case OP_Emperor:
		case OP_RockStar:
		case OP_Q:
		case OP_God:
		case OP_Owner:
			{	// Owner-level commands
			}
		case OP_SysOp:
			{	// SysOp-level commands
			}
		case OP_SuperModerator:
			{	// SuperModerator-level commands
			}
		case OP_Moderator:
			{	// Moderator-level commands
			}
		case OP_Limited:
			{	// Limited-level commands
			}
		case OP_Player:
			{	// Player-level commands
			}
		}

		return;
	}

	// Specific command help

	switch (l)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
		}
	case OP_Moderator:
		{	// Moderator-level commands
		}
	case OP_Limited:
		{	// Limited-level commands
		}
	case OP_Player:
		{	// Player-level commands
		}
	}
}

void botInfo::gotRemote(char *p, Command *c, Operator_Level l)
{
	if (!c) return;

	switch (l)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
		}
	case OP_Moderator:
		{	// Moderator-level commands
		}
	case OP_Limited:
		{	// Limited-level commands
		}
	case OP_Player:
		{	// Player-level commands
		}
	}
}
